package org.cloudgraph.test.datatypes.query;

import org.plasma.sdo.helper.PlasmaTypeHelper;
import org.plasma.query.dsl.DomainRoot;
import org.plasma.query.dsl.PathNode;
import org.plasma.query.DataProperty;
import org.plasma.query.dsl.DataNode;
import org.plasma.query.Expression;

import org.cloudgraph.test.datatypes.Concurrent;
import org.cloudgraph.test.datatypes.Node;

import org.cloudgraph.test.datatypes.query.QNode;
import org.cloudgraph.test.datatypes.StringNode;

/**
 * Generated Domain Specific Language (DSL) implementation class representing the domain model entity <b>StringNode</b>.
 *
 * <p></p>
 * <b>Data Store Mapping:</b>
 * Corresponds to the physical data store entity <b>STRND</b>.
 *
 */
public class QStringNode extends DomainRoot
{


	private QStringNode() {
		super(PlasmaTypeHelper.INSTANCE.getType(StringNode.class));
	}
	
	/**
	 * Constructor which instantiates a domain query path node. A path may
	 * span multiple namespaces and therefore Java inplementation packages
	 * based on the <a href="http://docs.plasma-sdo.org/api/org/plasma/config/PlasmaConfiguration.html">Condiguration</a>.
	 * Note: while this constructor is public, it is not for application use!
	 * @param source the source path node
	 * @param sourceProperty the source property logical name
	 */
	public QStringNode(PathNode source, String sourceProperty) {
		super(source, sourceProperty);
	}
	
	/**
	 * Constructor which instantiates a domain query path node. A path may
	 * span multiple namespaces and therefore Java inplementation packages
	 * based on the <a href="http://docs.plasma-sdo.org/api/org/plasma/config/PlasmaConfiguration.html">Condiguration</a>.
	 * Note: while this constructor is public, it is not for application use!
	 * @param source the source path node
	 * @param sourceProperty the source property logical name
	 * @param expr the path predicate expression
	 */
	public QStringNode(PathNode source, String sourceProperty, Expression expr) {
		super(source, sourceProperty, expr);
	}

	/**
	 * Returns a new DSL query for <a href="http://docs.plasma-sdo.org/api/org/plasma/sdo/PlasmaType.html">Type</a> <b>StringNode</b> which can be used either as a query root or
	 * as the start (entry point) for a new path predicate expression.
	 * @return a new DSL query
	 */
	public static QStringNode newQuery() {
		return new QStringNode();
	}

	/**
	 * Returns a DSL data element for property, <b>YearField</b>.
	 * @return a DSL data element for property, <b>YearField</b>.
	 */
	public DataProperty YearField() {
		return new DataNode(this, Node.YEAR_FIELD);
	}

	/**
	 * Returns a DSL data element for property, <b>booleanField</b>.
	 * @return a DSL data element for property, <b>booleanField</b>.
	 */
	public DataProperty booleanField() {
		return new DataNode(this, Node.BOOLEAN_FIELD);
	}

	/**
	 * Returns a DSL data element for property, <b>byteField</b>.
	 * @return a DSL data element for property, <b>byteField</b>.
	 */
	public DataProperty byteField() {
		return new DataNode(this, Node.BYTE_FIELD);
	}

	/**
	 * Returns a DSL data element for property, <b>bytesField</b>.
	 * @return a DSL data element for property, <b>bytesField</b>.
	 */
	public DataProperty bytesField() {
		return new DataNode(this, Node.BYTES_FIELD);
	}

	/**
	 * Returns a DSL data element for property, <b>characterField</b>.
	 * @return a DSL data element for property, <b>characterField</b>.
	 */
	public DataProperty characterField() {
		return new DataNode(this, Node.CHARACTER_FIELD);
	}

	/**
	 * Returns a DSL query element for reference property, <b>child</b>.
	 * @return a DSL query element for reference property, <b>child</b>.
	 */
	public QNode child() {
		return new QNode(this, Node.CHILD);
	}
	
	/**
	 * Returns a DSL query element for reference property, <b>child</b>, while adding the given path predicate expression. 
	 * Path predicate expressions are used to restrict
	 * the query results for a collection property within a <a href="http://docs.plasma-sdo.org/api/org/plasma/sdo/PlasmaDataGraph.html">DataGraph</a>.
	 * @param expr the path predicate expression
	 * @return a DSL query element for reference property, <b>child</b>.
	 */
	public QNode child(Expression expr) {
		return new QNode(this, Node.CHILD, expr);
	}

	/**
	 * Returns a DSL data element for property, <b>createdBy</b>.
	 * @return a DSL data element for property, <b>createdBy</b>.
	 */
	public DataProperty createdBy() {
		return new DataNode(this, Concurrent.CREATED_BY);
	}

	/**
	 * Returns a DSL data element for property, <b>createdOn</b>.
	 * @return a DSL data element for property, <b>createdOn</b>.
	 */
	public DataProperty createdOn() {
		return new DataNode(this, Concurrent.CREATED_ON);
	}

	/**
	 * Returns a DSL data element for property, <b>dateField</b>.
	 * @return a DSL data element for property, <b>dateField</b>.
	 */
	public DataProperty dateField() {
		return new DataNode(this, Node.DATE_FIELD);
	}

	/**
	 * Returns a DSL data element for property, <b>dateTimeField</b>.
	 * @return a DSL data element for property, <b>dateTimeField</b>.
	 */
	public DataProperty dateTimeField() {
		return new DataNode(this, Node.DATE_TIME_FIELD);
	}

	/**
	 * Returns a DSL data element for property, <b>dayField</b>.
	 * @return a DSL data element for property, <b>dayField</b>.
	 */
	public DataProperty dayField() {
		return new DataNode(this, Node.DAY_FIELD);
	}

	/**
	 * Returns a DSL data element for property, <b>decimalField</b>.
	 * @return a DSL data element for property, <b>decimalField</b>.
	 */
	public DataProperty decimalField() {
		return new DataNode(this, Node.DECIMAL_FIELD);
	}

	/**
	 * Returns a DSL data element for property, <b>doubleField</b>.
	 * @return a DSL data element for property, <b>doubleField</b>.
	 */
	public DataProperty doubleField() {
		return new DataNode(this, Node.DOUBLE_FIELD);
	}

	/**
	 * Returns a DSL data element for property, <b>durationField</b>.
	 * @return a DSL data element for property, <b>durationField</b>.
	 */
	public DataProperty durationField() {
		return new DataNode(this, Node.DURATION_FIELD);
	}

	/**
	 * Returns a DSL data element for property, <b>floatField</b>.
	 * @return a DSL data element for property, <b>floatField</b>.
	 */
	public DataProperty floatField() {
		return new DataNode(this, Node.FLOAT_FIELD);
	}

	/**
	 * Returns a DSL data element for property, <b>intField</b>.
	 * @return a DSL data element for property, <b>intField</b>.
	 */
	public DataProperty intField() {
		return new DataNode(this, Node.INT_FIELD);
	}

	/**
	 * Returns a DSL data element for property, <b>integerField</b>.
	 * @return a DSL data element for property, <b>integerField</b>.
	 */
	public DataProperty integerField() {
		return new DataNode(this, Node.INTEGER_FIELD);
	}

	/**
	 * Returns a DSL data element for property, <b>lastAccessedOn</b>.
	 * @return a DSL data element for property, <b>lastAccessedOn</b>.
	 */
	public DataProperty lastAccessedOn() {
		return new DataNode(this, Concurrent.LAST_ACCESSED_ON);
	}

	/**
	 * Returns a DSL data element for property, <b>lastModifiedBy</b>.
	 * @return a DSL data element for property, <b>lastModifiedBy</b>.
	 */
	public DataProperty lastModifiedBy() {
		return new DataNode(this, Concurrent.LAST_MODIFIED_BY);
	}

	/**
	 * Returns a DSL data element for property, <b>lastModifiedOn</b>.
	 * @return a DSL data element for property, <b>lastModifiedOn</b>.
	 */
	public DataProperty lastModifiedOn() {
		return new DataNode(this, Concurrent.LAST_MODIFIED_ON);
	}

	/**
	 * Returns a DSL data element for property, <b>levelNum</b>.
	 * @return a DSL data element for property, <b>levelNum</b>.
	 */
	public DataProperty levelNum() {
		return new DataNode(this, Concurrent.LEVEL_NUM);
	}

	/**
	 * Returns a DSL data element for property, <b>longField</b>.
	 * @return a DSL data element for property, <b>longField</b>.
	 */
	public DataProperty longField() {
		return new DataNode(this, Node.LONG_FIELD);
	}

	/**
	 * Returns a DSL data element for property, <b>monthDayField</b>.
	 * @return a DSL data element for property, <b>monthDayField</b>.
	 */
	public DataProperty monthDayField() {
		return new DataNode(this, Node.MONTH_DAY_FIELD);
	}

	/**
	 * Returns a DSL data element for property, <b>monthField</b>.
	 * @return a DSL data element for property, <b>monthField</b>.
	 */
	public DataProperty monthField() {
		return new DataNode(this, Node.MONTH_FIELD);
	}

	/**
	 * Returns a DSL data element for property, <b>name</b>.
	 * @return a DSL data element for property, <b>name</b>.
	 */
	public DataProperty name() {
		return new DataNode(this, Node.NAME);
	}

	/**
	 * Returns a DSL data element for property, <b>objectField</b>.
	 * @return a DSL data element for property, <b>objectField</b>.
	 */
	public DataProperty objectField() {
		return new DataNode(this, Node.OBJECT_FIELD);
	}

	/**
	 * Returns a DSL query element for reference property, <b>parent</b>.
	 * @return a DSL query element for reference property, <b>parent</b>.
	 */
	public QNode parent() {
		return new QNode(this, Node.PARENT);
	}

	/**
	 * Returns a DSL data element for property, <b>rootId</b>.
	 * @return a DSL data element for property, <b>rootId</b>.
	 */
	public DataProperty rootId() {
		return new DataNode(this, Node.ROOT_ID);
	}

	/**
	 * Returns a DSL data element for property, <b>seqId</b>.
	 * @return a DSL data element for property, <b>seqId</b>.
	 */
	public DataProperty seqId() {
		return new DataNode(this, Concurrent.SEQ_ID);
	}

	/**
	 * Returns a DSL data element for property, <b>sequenceNum</b>.
	 * @return a DSL data element for property, <b>sequenceNum</b>.
	 */
	public DataProperty sequenceNum() {
		return new DataNode(this, Concurrent.SEQUENCE_NUM);
	}

	/**
	 * Returns a DSL data element for property, <b>shortField</b>.
	 * @return a DSL data element for property, <b>shortField</b>.
	 */
	public DataProperty shortField() {
		return new DataNode(this, Node.SHORT_FIELD);
	}

	/**
	 * Returns a DSL data element for property, <b>stringField</b>.
	 * @return a DSL data element for property, <b>stringField</b>.
	 */
	public DataProperty stringField() {
		return new DataNode(this, Node.STRING_FIELD);
	}

	/**
	 * Returns a DSL data element for property, <b>stringsField</b>.
	 * @return a DSL data element for property, <b>stringsField</b>.
	 */
	public DataProperty stringsField() {
		return new DataNode(this, Node.STRINGS_FIELD);
	}

	/**
	 * Returns a DSL data element for property, <b>timeField</b>.
	 * @return a DSL data element for property, <b>timeField</b>.
	 */
	public DataProperty timeField() {
		return new DataNode(this, Node.TIME_FIELD);
	}

	/**
	 * Returns a DSL data element for property, <b>uriField</b>.
	 * @return a DSL data element for property, <b>uriField</b>.
	 */
	public DataProperty uriField() {
		return new DataNode(this, Node.URI_FIELD);
	}

	/**
	 * Returns a DSL data element for property, <b>yearMonthDayField</b>.
	 * @return a DSL data element for property, <b>yearMonthDayField</b>.
	 */
	public DataProperty yearMonthDayField() {
		return new DataNode(this, Node.YEAR_MONTH_DAY_FIELD);
	}

	/**
	 * Returns a DSL data element for property, <b>yearMonthField</b>.
	 * @return a DSL data element for property, <b>yearMonthField</b>.
	 */
	public DataProperty yearMonthField() {
		return new DataNode(this, Node.YEAR_MONTH_FIELD);
	}
}